## 上市公司基本信息

接口：stock_company，可以通过数据工具调试和查看数据。

描述：获取上市公司基础信息，单次提取4500条，可以根据交易所分批提取

积分：用户需要至少120积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必须 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| exchange | str | N | 交易所代码 ，SSE上交所 SZSE深交所 BSE北交所 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| com_name | str | Y | 公司全称 |
| com_id | str | Y | 统一社会信用代码 |
| exchange | str | Y | 交易所代码 |
| chairman | str | Y | 法人代表 |
| manager | str | Y | 总经理 |
| secretary | str | Y | 董秘 |
| reg_capital | float | Y | 注册资本(万元) |
| setup_date | str | Y | 注册日期 |
| province | str | Y | 所在省份 |
| city | str | Y | 所在城市 |
| introduction | str | N | 公司介绍 |
| website | str | Y | 公司主页 |
| email | str | Y | 电子邮件 |
| office | str | N | 办公室 |
| employees | int | Y | 员工人数 |
| main_business | str | N | 主要业务及产品 |
| business_scope | str | N | 经营范围 |

接口示例

```python
pro = ts.pro_api()

#或者
#pro = ts.pro_api('your token')

df = pro.stock_company(exchange='SZSE', fields='ts_code,chairman,manager,secretary,reg_capital,setup_date,province')
```

数据示例

```python
ts_code chairman manager secretary   reg_capital setup_date province  \
0     000001.SZ      谢永林     胡跃飞        周强  1.717041e+06   19871222       广东   
```